Crate pyszczek

Crate pyszczek 

Functions

free_string
Optional: Function to free the memory (call this from Ruby when done)
nutek
Return a string with a cat face The caller is responsible for freeing the memory using the free_string function
nutek_logo
Return a string with a Nutek Security logo The caller is responsible for freeing the memory using the free_string function